@@ -4,7 +4,7 @@ use warnings;
 
 package Dist::Zilla::Plugin::Test::CheckChanges;
 # ABSTRACT: Release tests for checking changes
-our $VERSION = '2.000003'; # VERSION
+our $VERSION = '2.000004'; # VERSION
 use Moose;
 
 extends 'Dist::Zilla::Plugin::InlineFiles';
@@ -14,7 +14,7 @@ no Moose;
 
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
@@ -22,7 +22,7 @@ Dist::Zilla::Plugin::Test::CheckChanges - Release tests for checking changes
 
 =head1 VERSION
 
-version 2.000003
+version 2.000004
 
 =head1 SYNOPSIS
 
@@ -37,9 +37,6 @@ following file:
 
   xt/release/check-changes.t - a standard Test::CheckChanges test
 
-=for test_synopsis 1;
-__END__
-
 =head1 AVAILABILITY
 
 The project homepage is L<http://metacpan.org/release/Dist-Zilla-Plugin-Test-CheckChanges/>.
